@@ -3,7 +3,7 @@ from bdflib import glyph_combining, model
 
 
 class TestBuildUnicodeDecompositions(unittest.TestCase):
-    def test_basic_functionality(self):
+    def test_basic_functionality(self) -> None:
         """
         build_unicode_decompositions should run without crashing.
         """
@@ -29,7 +29,7 @@ class TestBuildUnicodeDecompositions(unittest.TestCase):
                 self.assertEqual(len(char), 1)
                 self.assertEqual(type(combining_class), int)
 
-    def test_base_dotless_i_and_j(self):
+    def test_base_dotless_i_and_j(self) -> None:
         """
         Accented "i" should be based on a dotless i.
         """
@@ -54,8 +54,7 @@ class TestBuildUnicodeDecompositions(unittest.TestCase):
 
 
 class TestFontFiller(unittest.TestCase):
-    def setUp(self):
-
+    def setUp(self) -> None:
         # Create a simple font with two characters
         self.font = model.Font(b"TestFont", 12, 100, 100)
         self.font.new_glyph_from_data(
@@ -80,7 +79,7 @@ class TestFontFiller(unittest.TestCase):
 
         self.filler = glyph_combining.FontFiller(self.font, self.decompositions)
 
-    def test_basic_functionality(self):
+    def test_basic_functionality(self) -> None:
         """
         We succeed if we have a decomposition and the components.
         """
@@ -94,7 +93,7 @@ class TestFontFiller(unittest.TestCase):
         print(glyph)
         self.assertEqual(str(glyph), "|#.#.\n" "#---#")
 
-    def test_recursive_functionality(self):
+    def test_recursive_functionality(self) -> None:
         """
         We succeed even if we can only get the components recursively.
         """
@@ -108,7 +107,7 @@ class TestFontFiller(unittest.TestCase):
         print(glyph)
         self.assertEqual(str(glyph), "|#.#...#.#.\n" "#---#-#---#")
 
-    def test_character_present(self):
+    def test_character_present(self) -> None:
         """
         We succeed if the char is already in the font.
         """
@@ -117,7 +116,7 @@ class TestFontFiller(unittest.TestCase):
         self.assertEqual(self.filler.unknown_classes, {})
         self.assertEqual(added, True)
 
-    def test_missing_decomposition(self):
+    def test_missing_decomposition(self) -> None:
         """
         We fail if there's no decomposition for the given character.
         """
@@ -126,7 +125,7 @@ class TestFontFiller(unittest.TestCase):
         self.assertEqual(self.filler.unknown_classes, {})
         self.assertEqual(added, False)
 
-    def test_missing_recursive_decomposition(self):
+    def test_missing_recursive_decomposition(self) -> None:
         """
         We fail if there's a decomposition but no components for a character.
         """
@@ -135,7 +134,7 @@ class TestFontFiller(unittest.TestCase):
         self.assertEqual(self.filler.unknown_classes, {})
         self.assertEqual(added, False)
 
-    def test_unknown_combining_class(self):
+    def test_unknown_combining_class(self) -> None:
         """
         We fail if there's a decomposition but we don't know how to use it.
         """
@@ -144,7 +143,7 @@ class TestFontFiller(unittest.TestCase):
         self.assertEqual(self.filler.unknown_classes, {256: 1})
         self.assertEqual(added, False)
 
-    def test_add_decomposable_glyphs_to_font(self):
+    def test_add_decomposable_glyphs_to_font(self) -> None:
         """
         Add all the glyphs we can to the given font.
         """
@@ -158,7 +157,9 @@ class TestFontFiller(unittest.TestCase):
 
 
 class TestFontFillerCombiningAbove(unittest.TestCase):
-    def _build_composing_above_font(self, set_cap_height=False):
+    def _build_composing_above_font(
+        self, set_cap_height: bool = False
+    ) -> model.Font:
         """
         Return a font with glyphs useful for testing COMBINING ABOVE.
         """
@@ -244,7 +245,7 @@ class TestFontFillerCombiningAbove(unittest.TestCase):
 
         return font
 
-    def test_composing_even_above_odd(self):
+    def test_composing_even_above_odd(self) -> None:
         font = self._build_composing_above_font()
 
         O_macron = font[ord("I")]
@@ -254,7 +255,7 @@ class TestFontFillerCombiningAbove(unittest.TestCase):
             "####\n" "|...\n" "|#..\n" "#.#.\n" "#.#.\n" "+#--",
         )
 
-    def test_composing_odd_above_odd(self):
+    def test_composing_odd_above_odd(self) -> None:
         font = self._build_composing_above_font()
 
         O_caron = font[ord("J")]
@@ -263,8 +264,7 @@ class TestFontFillerCombiningAbove(unittest.TestCase):
             str(O_caron), "|#.\n" "#.#\n" "|..\n" "|#.\n" "#.#\n" "#.#\n" "+#-"
         )
 
-    def test_composing_above_without_CAP_HEIGHT(self):
-
+    def test_composing_above_without_CAP_HEIGHT(self) -> None:
         # Build the font without CAP_HEIGHT set.
         font = self._build_composing_above_font(False)
 
@@ -281,7 +281,7 @@ class TestFontFillerCombiningAbove(unittest.TestCase):
             str(o_caron), "|#.\n" "#.#\n" "|..\n" "|..\n" "|#.\n" "#.#\n" "+#-"
         )
 
-    def test_composing_above_with_CAP_HEIGHT(self):
+    def test_composing_above_with_CAP_HEIGHT(self) -> None:
         # Build the font with CAP_HEIGHT set.
         font = self._build_composing_above_font(True)
 
@@ -301,7 +301,7 @@ class TestFontFillerCombiningAbove(unittest.TestCase):
             str(o_caron), "|#.\n" "#.#\n" "|..\n" "|#.\n" "#.#\n" "+#-"
         )
 
-    def test_composing_above_blank_base(self):
+    def test_composing_above_blank_base(self) -> None:
         """
         Composing on top of a blank base char should work.
         """
@@ -327,7 +327,7 @@ class TestFontFillerCombiningAbove(unittest.TestCase):
 
 
 class TestFontFillerCombiningBelow(unittest.TestCase):
-    def _build_composing_below_font(self):
+    def _build_composing_below_font(self) -> model.Font:
         """
         Return a font with glyphs useful for testing COMBINING BELOW.
         """
@@ -421,7 +421,7 @@ class TestFontFillerCombiningBelow(unittest.TestCase):
 
         return font
 
-    def test_composing_even_below_odd(self):
+    def test_composing_even_below_odd(self) -> None:
         font = self._build_composing_below_font()
 
         Y_macron = font[ord("I")]
@@ -430,7 +430,7 @@ class TestFontFillerCombiningBelow(unittest.TestCase):
             str(Y_macron), "#.#.\n" "#.#.\n" "|#..\n" "+#--\n" "|...\n" "####"
         )
 
-    def test_composing_odd_below_odd(self):
+    def test_composing_odd_below_odd(self) -> None:
         font = self._build_composing_below_font()
 
         Y_dot = font[ord("J")]
@@ -439,8 +439,7 @@ class TestFontFillerCombiningBelow(unittest.TestCase):
             str(Y_dot), "#.#\n" "#.#\n" "|#.\n" "+#-\n" "|..\n" "|#."
         )
 
-    def test_composing_below_clears_descenders(self):
-
+    def test_composing_below_clears_descenders(self) -> None:
         font = self._build_composing_below_font()
 
         # Upper case and lower-case should have the accent at the same place.
@@ -456,7 +455,7 @@ class TestFontFillerCombiningBelow(unittest.TestCase):
             str(y_dot), "#.#\n" "#.#\n" "+##\n" "|.#\n" "##.\n" "|..\n" "|#."
         )
 
-    def test_composing_below_blank_base(self):
+    def test_composing_below_blank_base(self) -> None:
         """
         Composing on top of a blank base char should work.
         """
