@@ -4,7 +4,7 @@ from bdflib import model
 
 
 class TestFont(unittest.TestCase):
-    def test_basic_properties(self):
+    def test_basic_properties(self) -> None:
         f = model.Font(name=b"TestFont", ptSize=12, xdpi=100, ydpi=100)
 
         # Test that we're storing font fields as attributes.
@@ -13,12 +13,21 @@ class TestFont(unittest.TestCase):
         self.assertEqual(f.xdpi, 100)
         self.assertEqual(f.ydpi, 100)
 
-    def test_property_setting(self):
+    def test_property_setting(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         f[b"CHARSET_REGISTRY"] = b"iso8859"
         self.assertEqual(f[b"CHARSET_REGISTRY"], b"iso8859")
+        self.assertEqual(f.get(b"CHARSET_REGISTRY"), b"iso8859")
 
-    def test_property_iteration(self):
+    def test_property_removal(self) -> None:
+        f = model.Font(b"TestFont", 12, 100, 100)
+        # Add the property
+        f[b"CHARSET_REGISTRY"] = b"iso8859"
+        # Remove the property
+        del f[b"CHARSET_REGISTRY"]
+        self.assertNotIn(b"CHARSET_REGISTRY", f)
+
+    def test_property_iteration(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         self.assertEqual(list(f.property_names()), [])
 
@@ -30,7 +39,23 @@ class TestFont(unittest.TestCase):
             [b"CUSTOM_PROP1", b"CUSTOM_PROP2"],
         )
 
-    def test_codepoint_iteration(self):
+    def test_add_glyph_with_codepoint(self) -> None:
+        f = model.Font(b"TestFont", 12, 100, 100)
+        g = f.new_glyph_from_data(b"TestGlyph", [0b10, 0b01], 0, 0, 2, 2, 3, 5)
+
+        self.assertEqual(f[5], g)
+        self.assertEqual(f.get(5), g)
+
+    def test_codepoint_removal(self) -> None:
+        f = model.Font(b"TestFont", 12, 100, 100)
+        g = f.new_glyph_from_data(b"TestGlyph", [0b10, 0b01], 0, 0, 2, 2, 3, 5)
+
+        del f[5]
+
+        self.assertNotIn(5, f.codepoints())
+        self.assertNotIn(g, f.glyphs)
+
+    def test_codepoint_iteration(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
 
         # Add glyphs at code-points out-of-order.
@@ -44,7 +69,13 @@ class TestFont(unittest.TestCase):
 
         self.assertEqual(codepoints, [5, 16, 37, 93])
 
-    def test_comments(self):
+    def test_font_does_not_contain_other_things(self) -> None:
+        f = model.Font(b"TestFont", 12, 100, 100)
+        # The font only stores bytestrings (properties) and ints (codepoints),
+        # not other random things.
+        self.assertNotIn((1, 2, 3), f)
+
+    def test_comments(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         f.add_comment(b"This is another comment")
         f.add_comment(b"hello, world!\nMultiple lines!")
@@ -57,9 +88,9 @@ class TestFont(unittest.TestCase):
             ],
         )
 
-    def test_font_copying(self):
+    def test_font_copying(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
-        g = f.new_glyph_from_data(
+        f.new_glyph_from_data(
             b"TestGlyph",
             [
                 0b0001,
@@ -76,8 +107,21 @@ class TestFont(unittest.TestCase):
             8,
             1,
         )
+        f.add_comment(b"This is another comment")
+        f.add_comment(b"hello, world!\nMultiple lines!")
+        f[b"SOMEPROPERTY"] = b"Some value"
 
         f2 = f.copy()
+        self.assertEqual(
+            f2.get_comments(),
+            [
+                b"This is another comment",
+                b"hello, world!",
+                b"Multiple lines!",
+            ],
+        )
+        self.assertEqual(f2[b"SOMEPROPERTY"], b"Some value")
+
         g2 = f2[1]
 
         self.assertEqual(g2.name, b"TestGlyph")
@@ -99,7 +143,7 @@ class TestFont(unittest.TestCase):
 
 
 class TestGlyph(unittest.TestCase):
-    def test_glyph_creation(self):
+    def test_glyph_creation(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(
             b"TestGlyph",
@@ -136,15 +180,38 @@ class TestGlyph(unittest.TestCase):
         self.assertEqual(g.codepoint, 1)
         self.assertEqual(f[g.codepoint], g)
 
-    def test_duplicate_codepoints(self):
+    def test_duplicate_codepoints(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
-        g = f.new_glyph_from_data(b"TestGlyph1", codepoint=1)
+        f.new_glyph_from_data(b"TestGlyph1", codepoint=1)
+
+        self.assertEqual(len(f.glyphs), 1)
 
         self.assertRaises(
-            model.GlyphExists, f.new_glyph_from_data, b"TestGlyph2", codepoint=1
+            model.GlyphExists,
+            f.new_glyph_from_data,
+            b"TestGlyph2",
+            codepoint=1,
         )
 
-    def test_glyph_merging_no_op(self):
+        # The glyph should not have been added to the font
+        self.assertEqual(len(f.glyphs), 1)
+
+    def test_accept_duplicate_codepoints_for_identical_glyphs(self) -> None:
+        f = model.Font(b"TestFont", 12, 100, 100)
+        g1 = f.new_glyph_from_data(b"TestGlyph1", codepoint=1)
+
+        self.assertEqual(len(f.glyphs), 1)
+
+        # Add a second glyph with the same content and codepoint
+        g2 = f.new_glyph_from_data(b"TestGlyph1", codepoint=1)
+
+        # Still only one glyph in the font
+        self.assertEqual(len(f.glyphs), 1)
+
+        # Should have returned the original glyph as the "new" glyph
+        self.assertIs(g1, g2)
+
+    def test_glyph_merging_no_op(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(b"TestGlyph", [0b10, 0b01], 0, 0, 2, 2, 3, 1)
 
@@ -161,7 +228,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_merging_above(self):
+    def test_glyph_merging_above(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(b"TestGlyph", [0b10, 0b01], 0, 0, 2, 2, 3, 1)
 
@@ -184,7 +251,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_merging_below(self):
+    def test_glyph_merging_below(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(b"TestGlyph", [0b01, 0b10], 0, 0, 2, 2, 3, 1)
 
@@ -207,7 +274,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_merging_left(self):
+    def test_glyph_merging_left(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(b"TestGlyph", [0b10, 0b01], 0, 0, 2, 2, 3, 1)
 
@@ -227,7 +294,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_merging_right(self):
+    def test_glyph_merging_right(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(b"TestGlyph", [0b10, 0b01], 0, 0, 2, 2, 3, 1)
 
@@ -246,7 +313,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_merging_offset_glyph(self):
+    def test_glyph_merging_offset_glyph(self) -> None:
         """
         Merging a glyph whose bitmap doesn't start at (0,0)
         """
@@ -269,7 +336,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_merging(self):
+    def test_glyph_merging(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(b"TestGlyph", [0b10, 0b01], 0, 0, 2, 2, 3, 1)
 
@@ -288,8 +355,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_printing(self):
-
+    def test_glyph_printing(self) -> None:
         # A small circle
         glyph_data = [
             0b01110,
@@ -332,7 +398,7 @@ class TestGlyph(unittest.TestCase):
             ],
         )
 
-    def test_glyph_get_ascent_and_descent(self):
+    def test_glyph_get_ascent_and_descent(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
 
         # For a simple glyph at the origin, ascent and descent should match the
@@ -368,7 +434,7 @@ class TestGlyph(unittest.TestCase):
         self.assertEqual(g.get_ascent(), 1)
         self.assertEqual(g.get_descent(), 1)
 
-    def test_iter_pixels(self):
+    def test_iter_pixels(self) -> None:
         f = model.Font(b"TestFont", 12, 100, 100)
         g = f.new_glyph_from_data(
             name=b"LATIN SMALL LETTER H",
